##
## Config Screen for ExtendedServiceInfo-Converter
## by AliAbdul
##
from Plugins.Plugin import PluginDescriptor
from Components.ActionMap import ActionMap
from Components.config import config, ConfigSelection, ConfigSubsection, ConfigYesNo, getConfigListEntry
from Components.ConfigList import ConfigListScreen
from Components.Label import Label
from Screens.Screen import Screen

##############################################################################

config.plugins.ExtendedServiceInfo = ConfigSubsection()
config.plugins.ExtendedServiceInfo.showServiceNumber = ConfigYesNo(default = True)
config.plugins.ExtendedServiceInfo.showOrbitalPosition = ConfigYesNo(default = True)
config.plugins.ExtendedServiceInfo.orbitalPositionType = ConfigSelection(choices={"position": _("Position"), "name": _("Name")}, default="position")

##############################################################################

class InfoBarConfig(ConfigListScreen, Screen):
	skin = """
		<screen position="80,220" size="560,150" title="InfoBar Config">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="140,0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="280,0" size="140,40" transparent="1" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="420,0" size="140,40" transparent="1" alphatest="on" />
			<widget name="key_green" position="140,0" zPosition="1" size="140,40" font="Regular;20" valign="center" halign="center" backgroundColor="#1f771f" transparent="1" />
			<widget name="config" position="0,45" size="560,90" scrollbarMode="showOnDemand" />
		</screen>"""

	def __init__(self, session):
		Screen.__init__(self, session)
		
		self["key_green"] = Label(_("Save"))
		
		list = []
		list.append(getConfigListEntry(_("Show Service-Number:"), config.plugins.ExtendedServiceInfo.showServiceNumber))
		list.append(getConfigListEntry(_("Show Orbital-Position:"), config.plugins.ExtendedServiceInfo.showOrbitalPosition))
		list.append(getConfigListEntry(_("Show type of Orbital-Position:"), config.plugins.ExtendedServiceInfo.orbitalPositionType))
		ConfigListScreen.__init__(self, list)
		
		self["actions"] = ActionMap(["OkCancelActions", "ColorActions"], {"green": self.save, "cancel": self.exit}, -1)

	def save(self):
		for x in self["config"].list:
			x[1].save()
		self.close()

	def exit(self):
		for x in self["config"].list:
			x[1].cancel()
		self.close()

##############################################################################

def openInfoBarConfig(session, **kwargs):
	session.open(InfoBarConfig)

def startInfoBarConfig(menuid):
	if menuid != "system":
		return [ ]
	return [(_("InfoBar..."), openInfoBarConfig, "infobar_config", None)]

##############################################################################

def Plugins(**kwargs):
	return PluginDescriptor(name=_("InfoBar..."), where=PluginDescriptor.WHERE_MENU, fnc=startInfoBarConfig)
